@@ -2,8 +2,8 @@
  * International Union of Pure and Applied Chemistry (IUPAC)
  * International Chemical Identifier (InChI)
  * Version 1
- * Software version 1.00
- * April 13, 2005
+ * Software version 1.01
+ * May 16, 2006
  * Developed at NIST
  */
 
@@ -16,9 +16,10 @@ extern "C" {
 #endif
 #endif
 int bCanAtomBeAStereoCenter( char *elname, S_CHAR charge, S_CHAR radical );
-int bCanInpAtomBeAStereoCenter( inp_ATOM *at, int cur_at );
+int bCanInpAtomBeAStereoCenter( inp_ATOM *at, int cur_at, int bPointedEdgeStereo );
 int bCanAtomHaveAStereoBond( char *elname, S_CHAR charge, S_CHAR radical );
 int bCanAtomBeTerminalAllene( char *elname, S_CHAR charge, S_CHAR radical );
+int bCanAtomBeMiddleAllene( char *elname, S_CHAR charge, S_CHAR radical );
 int bAtomHasValence3( char *elname, S_CHAR charge, S_CHAR radical );
 int set_stereo_parity( inp_ATOM* at, sp_ATOM* at_output, int num_at, int num_removed_H,
                        int *nMaxNumStereoAtoms, int *nMaxNumStereoBonds, INCHI_MODE nMode,
@@ -26,6 +27,11 @@ int set_stereo_parity( inp_ATOM* at, sp_ATOM* at_output, int num_at, int num_rem
 int get_opposite_sb_atom( inp_ATOM *at, int cur_atom, int icur2nxt,
                           int *pnxt_atom, int *pinxt2cur, int *pinxt_sb_parity_ord );
 
+#define PES_BIT_POINT_EDGE_STEREO    1
+#define PES_BIT_PHOSPHINE_STEREO     2
+#define PES_BIT_ARSINE_STEREO        4
+#define PES_BIT_FIX_SP3_BUG          8
+
 #ifndef INCHI_ALL_CPP
 #ifdef __cplusplus
 }
