@@ -2,13 +2,14 @@
  * International Union of Pure and Applied Chemistry (IUPAC)
  * International Chemical Identifier (InChI)
  * Version 1
- * Software version 1.00
- * April 13, 2005
+ * Software version 1.01
+ * May 16, 2006
  * Developed at NIST
  */
 
 /* inchi_dll_main.c : Defines the entry point for the DLL application. */
-#if defined(_WIN32) && defined(_USRDLL) && defined(_DEBUG)
+
+#if defined(_WIN32) && defined(_USRDLL) && defined(_DEBUG) && !(defined(__STDC__) && __STDC__ == 1)
 #include "inchi_dll_main.h"
 int INCHI_DLLMAIN_TYPE DllMain( HANDLE hModule, 
                        DWORD  ul_reason_for_call, 
