@@ -2,8 +2,8 @@
  * International Union of Pure and Applied Chemistry (IUPAC)
  * International Chemical Identifier (InChI)
  * Version 1
- * Software version 1.00
- * April 13, 2005
+ * Software version 1.01
+ * May 16, 2006
  * Developed at NIST
  */
 
@@ -34,6 +34,7 @@ typedef struct tagElData {
      int     nNormAtMass;  /* Atomic mass of the most abundant isotope */
      double  dAtMass;      /* exact mw of the most abundant isotope */
      int     nType;        /* METAL or METAL2 */
+     int     nElNegPauling10; /* Pauling electronegativity x 10; 0 => unknown */
      int     bDoNotAddH;   /* InChI does not add imlicit H to atoms that have bDoNotAddH != 0 */
      S_CHAR  cValence[NUM_ATOM_CHARGES][MAX_NUM_VALENCES];
 } ELDATA;
@@ -41,115 +42,115 @@ typedef struct tagElData {
 /* 2004=05-10: Added valences {1,3,5,7,} for As(2-) */
 
 const ELDATA ElData[] = {
-/*       avg  norm                        No  -------- Valence(s) of an ion or neutral atom -------------*/
-/*        mw  mass  exact mw     type     H   -2          -1          0           +1         +2          */
-{ "H",    1,   1,   1.007825035,     0 ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "D",    2,   2,   2.014101778,     0 ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "T",    3,   3,   3.016049268,     0 ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "He",   4,   4,   4.002600000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "Li",   7,   7,   7.016000000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Be",   9,   9,   9.012180000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "B",   11,  11,  11.009300000,     0 ,  0, {{3,},       {4,},       {3,},       {2,},       {1,}       }},
-{ "C",   12,  12,  12.000000000,     0 ,  0, {{2,},       {3,},       {4,},       {3,},       {2,}       }},
-{ "N",   14,  14,  14.003074000,     0 ,  0, {{1,},       {2,},       {3,5},      {4,},       {3,}       }},
-{ "O",   16,  16,  15.994914630,     0 ,  0, {{0,},       {1,},       {2,},       {3,5,},     {4,}       }},
-{ "F",   19,  19,  18.998403220,     0 ,  0, {{0,},       {0,},       {1,},       {2,},       {3,5}      }},
-{ "Ne",  20,  20,  19.992440000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "Na",  23,  23,  22.989770000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Mg",  24,  24,  23.985000000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "Al",  27,  27,  26.981540000, METAL ,  0, {{3,5,},     {4,},       {3,},       {2,},       {1,}       }},
-{ "Si",  28,  28,  27.976927100,     0 ,  0, {{2,},       {3,5},      {4,},       {3,},       {2,}       }},
-{ "P",   31,  31,  30.973762000,     0 ,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {4,},       {3,}       }},
-{ "S",   32,  32,  31.972070700,     0 ,  0, {{0,},       {1,3,5,7,}, {2,4,6},    {3,5,},     {4,}       }},
-{ "Cl",  35,  35,  34.968852730,     0 ,  0, {{0,},       {0,},       {1,3,5,7},  {2,4,6},    {3,5,}     }},
-{ "Ar",  40,  40,  39.962400000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "K",   39,  39,  38.963700000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Ca",  40,  40,  39.962600000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "Sc",  45,  45,  44.955910000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Ti",  48,  48,  47.947950000, METAL ,  1, {{0,},       {0,},       {3,4},      {0,},       {0,}       }},
-{ "V",   51,  51,  50.943960000, METAL ,  1, {{0,},       {0,},       {2,3,4,5,}, {0,},       {0,}       }},
-{ "Cr",  52,  52,  51.940500000, METAL ,  1, {{0,},       {0,},       {2,3,6,},   {0,},       {0,}       }},
-{ "Mn",  55,  55,  54.938050000, METAL2,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
-{ "Fe",  56,  56,  55.934900000, METAL2,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
-{ "Co",  59,  59,  58.933200000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Ni",  59,  58,  57.935300000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Cu",  64,  63,  62.929600000, METAL ,  1, {{0,},       {0,},       {1,2,},     {0,},       {0,}       }},
-{ "Zn",  65,  64,  63.929147000, METAL ,  1, {{0,},       {0,},       {2,},       {0,},       {0,}       }},
-{ "Ga",  70,  69,  68.925600000, METAL ,  0, {{3,5,},     {4,},       {3,},       {0,},       {1,}       }},
-{ "Ge",  73,  74,  73.921177400,     0 ,  0, {{2,4,6,},   {3,5,},     {4,},       {3,},       {0,}       }},
-{ "As",  75,  75,  74.921594200,     0 ,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {4,},       {3,}       }},
-{ "Se",  79,  80,  79.916519600,     0 ,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {4,}       }},
-{ "Br",  80,  79,  78.918336100,     0 ,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6,},   {3,5,}     }},
-{ "Kr",  84,  84,  83.911500000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "Rb",  85,  85,  84.911800000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Sr",  88,  88,  87.905600000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "Y",   89,  89,  88.905860000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Zr",  91,  90,  89.904700000, METAL ,  1, {{0,},       {0,},       {4,},       {0,},       {0,}       }},
-{ "Nb",  93,  93,  92.906400000, METAL ,  1, {{0,},       {0,},       {3,5,},     {0,},       {0,}       }},
-{ "Mo",  96,  98,  97.905400000, METAL ,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Tc",  98,  98,  97.907200000, METAL ,  1, {{0,},       {0,},       {7,},       {0,},       {0,}       }},
-{ "Ru", 101, 102, 101.904300000, METAL ,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
-{ "Rh", 103, 103, 102.905500000, METAL ,  1, {{0,},       {0,},       {2,3,4,},   {0,},       {0,}       }},
-{ "Pd", 106, 106, 105.903500000, METAL ,  1, {{0,},       {0,},       {2,4,},     {0,},       {0,}       }},
-{ "Ag", 108, 107, 106.905100000, METAL ,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Cd", 112, 114, 113.903400000, METAL ,  1, {{0,},       {0,},       {2,},       {0,},       {0,}       }},
-{ "In", 115, 115, 114.903900000, METAL ,  0, {{3,5,},     {2,4,},     {3,},       {0,},       {1,}       }},
-{ "Sn", 119, 120, 119.902200000, METAL2,  0, {{2,4,6,},   {3,5},      {2,4,},     {3,},       {0,}       }},
-{ "Sb", 122, 121, 120.903800000, METAL,   0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,},     {3,}       }},
-{ "Te", 128, 130, 129.906200000,     0 ,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,}     }},
-{ "I",  127, 127, 126.904500000,     0 ,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6},    {3,5,}     }},
-{ "Xe", 131, 132, 131.904100000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "Cs", 133, 133, 132.905430000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Ba", 137, 138, 137.905200000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "La", 139, 139, 138.906360000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Ce", 140, 140, 139.905400000, METAL2,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
-{ "Pr", 141, 141, 140.907660000, METAL2,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
-{ "Nd", 144, 142, 141.907719000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Pm", 145, 145, 144.912800000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Sm", 150, 152, 151.919700000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Eu", 152, 153, 152.921200000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Gd", 157, 158, 157.924099000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Tb", 159, 159, 158.925350000, METAL2,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
-{ "Dy", 163, 164, 163.929200000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }}, /*  mw rounding uncertain */
-{ "Ho", 165, 165, 164.930300000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Er", 167, 166, 165.930300000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Tm", 169, 169, 168.934230000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Yb", 173, 174, 173.938900000, METAL2,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
-{ "Lu", 175, 175, 174.940800000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Hf", 178, 180, 179.946600000, METAL ,  1, {{0,},       {0,},       {4,},       {0,},       {0,}       }},
-{ "Ta", 181, 181, 180.948010000, METAL ,  1, {{0,},       {0,},       {5,},       {0,},       {0,}       }},
-{ "W",  184, 184, 183.951000000, METAL2,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Re", 186, 187, 186.955800000, METAL2,  1, {{0,},       {0,},       {2,4,6,7,}, {0,},       {0,}       }},
-{ "Os", 190, 192, 191.961500000, METAL2,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
-{ "Ir", 192, 193, 192.962900000, METAL2,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
-{ "Pt", 195, 195, 194.964800000, METAL2,  1, {{0,},       {0,},       {2,4,},     {0,},       {0,}       }},
-{ "Au", 197, 197, 196.966560000, METAL ,  1, {{0,},       {0,},       {1,3,},     {0,},       {0,}       }},
-{ "Hg", 201, 202, 201.970617000, METAL2,  1, {{0,},       {0,},       {1,2,},     {0,},       {0,}       }},
-{ "Tl", 204, 205, 204.974400000, METAL2,  0, {{3,5,},     {2,4,},     {1,3,},     {0,},       {0,}       }},
-{ "Pb", 207, 208, 207.976627000, METAL2,  0, {{2,4,6,},   {3,5},      {2,4,},     {3,},       {0,}       }},
-{ "Bi", 209, 209, 208.980390000, METAL ,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,},     {3,}       }},
-{ "Po", 209, 209, 208.982400000, METAL2,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,}     }},
-{ "At", 210, 210, 209.987100000,     0 ,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6},    {3,5,}     }},
-{ "Rn", 222, 222, 222.017500000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
-{ "Fr", 223, 223, 223.019700000, METAL ,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Ra", 226, 226, 226.025410000, METAL ,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
-{ "Ac", 227, 227, 227.027750000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Th", 232, 232, 232.038050000, METAL2,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
-{ "Pa", 231, 231, 231.035880000, METAL2,  1, {{0,},       {0,},       {3,4,5,},   {0,},       {0,}       }},
-{ "U",  238, 238, 238.050790000, METAL2,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Np", 237, 237, 237.048170000, METAL2,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Pu", 244, 244, 244.064200000, METAL2,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Am", 243, 243, 243.061370000, METAL2,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
-{ "Cm", 247, 247, 247.070300000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Bk", 247, 247, 247.070300000, METAL ,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
-{ "Cf", 251, 251, 251.079600000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Es", 252, 252, 252.082800000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Fm", 257, 257, 257.095100000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "Md", 258, 258, 258.098600000, METAL ,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
-{ "No", 259, 259, 259.100900000, METAL ,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Lr", 260, 260, 260.105400000, METAL ,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "Rf", 261, 261, 261.108700000, METAL ,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
-{ "",     0,   0,   0.000000000,     0 ,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+/*       avg  norm                      El    No  -------- Valence(s) of an ion or neutral atom -------------*/
+/*        mw  mass  exact mw     type   neg   H   -2          -1          0           +1         +2          */
+{ "H",    1,   1,   1.007825035,     0 , 21,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "D",    2,   2,   2.014101778,     0 , 21,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "T",    3,   3,   3.016049268,     0 , 21,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "He",   4,   4,   4.002600000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "Li",   7,   7,   7.016000000, METAL , 10,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Be",   9,   9,   9.012180000, METAL , 15,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "B",   11,  11,  11.009300000,     0 , 20,  0, {{3,},       {4,},       {3,},       {2,},       {1,}       }},
+{ "C",   12,  12,  12.000000000,     0 , 25,  0, {{2,},       {3,},       {4,},       {3,},       {2,}       }},
+{ "N",   14,  14,  14.003074000,     0 , 30,  0, {{1,},       {2,},       {3,5},      {4,},       {3,}       }},
+{ "O",   16,  16,  15.994914630,     0 , 35,  0, {{0,},       {1,},       {2,},       {3,5,},     {4,}       }},
+{ "F",   19,  19,  18.998403220,     0 , 40,  0, {{0,},       {0,},       {1,},       {2,},       {3,5}      }},
+{ "Ne",  20,  20,  19.992440000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "Na",  23,  23,  22.989770000, METAL ,  9,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Mg",  24,  24,  23.985000000, METAL , 12,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "Al",  27,  27,  26.981540000, METAL , 15,  0, {{3,5,},     {4,},       {3,},       {2,},       {1,}       }},
+{ "Si",  28,  28,  27.976927100,     0 , 18,  0, {{2,},       {3,5},      {4,},       {3,},       {2,}       }},
+{ "P",   31,  31,  30.973762000,     0 , 21,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {4,},       {3,}       }},
+{ "S",   32,  32,  31.972070700,     0 , 25,  0, {{0,},       {1,3,5,7,}, {2,4,6},    {3,5,},     {4,}       }},
+{ "Cl",  35,  35,  34.968852730,     0 , 30,  0, {{0,},       {0,},       {1,3,5,7},  {2,4,6},    {3,5,}     }},
+{ "Ar",  40,  40,  39.962400000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "K",   39,  39,  38.963700000, METAL ,  8,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Ca",  40,  40,  39.962600000, METAL , 10,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "Sc",  45,  45,  44.955910000, METAL , 13,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Ti",  48,  48,  47.947950000, METAL , 15,  1, {{0,},       {0,},       {3,4},      {0,},       {0,}       }},
+{ "V",   51,  51,  50.943960000, METAL , 16,  1, {{0,},       {0,},       {2,3,4,5,}, {0,},       {0,}       }},
+{ "Cr",  52,  52,  51.940500000, METAL , 16,  1, {{0,},       {0,},       {2,3,6,},   {0,},       {0,}       }},
+{ "Mn",  55,  55,  54.938050000, METAL2, 15,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
+{ "Fe",  56,  56,  55.934900000, METAL2, 18,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
+{ "Co",  59,  59,  58.933200000, METAL2, 18,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Ni",  59,  58,  57.935300000, METAL2, 18,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Cu",  64,  63,  62.929600000, METAL , 19,  1, {{0,},       {0,},       {1,2,},     {0,},       {0,}       }},
+{ "Zn",  65,  64,  63.929147000, METAL , 16,  1, {{0,},       {0,},       {2,},       {0,},       {0,}       }},
+{ "Ga",  70,  69,  68.925600000, METAL , 18,  0, {{3,5,},     {4,},       {3,},       {0,},       {1,}       }},
+{ "Ge",  73,  74,  73.921177400,     0 , 18,  0, {{2,4,6,},   {3,5,},     {4,},       {3,},       {0,}       }},
+{ "As",  75,  75,  74.921594200,     0 , 20,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {4,},       {3,}       }},
+{ "Se",  79,  80,  79.916519600,     0 , 24,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {4,}       }},
+{ "Br",  80,  79,  78.918336100,     0 , 28,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6,},   {3,5,}     }},
+{ "Kr",  84,  84,  83.911500000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "Rb",  85,  85,  84.911800000, METAL ,  8,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Sr",  88,  88,  87.905600000, METAL , 10,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "Y",   89,  89,  88.905860000, METAL , 12,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Zr",  91,  90,  89.904700000, METAL , 14,  1, {{0,},       {0,},       {4,},       {0,},       {0,}       }},
+{ "Nb",  93,  93,  92.906400000, METAL , 16,  1, {{0,},       {0,},       {3,5,},     {0,},       {0,}       }},
+{ "Mo",  96,  98,  97.905400000, METAL , 18,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Tc",  98,  98,  97.907200000, METAL , 19,  1, {{0,},       {0,},       {7,},       {0,},       {0,}       }},
+{ "Ru", 101, 102, 101.904300000, METAL , 22,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
+{ "Rh", 103, 103, 102.905500000, METAL , 22,  1, {{0,},       {0,},       {2,3,4,},   {0,},       {0,}       }},
+{ "Pd", 106, 106, 105.903500000, METAL , 22,  1, {{0,},       {0,},       {2,4,},     {0,},       {0,}       }},
+{ "Ag", 108, 107, 106.905100000, METAL , 19,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Cd", 112, 114, 113.903400000, METAL , 17,  1, {{0,},       {0,},       {2,},       {0,},       {0,}       }},
+{ "In", 115, 115, 114.903900000, METAL , 17,  0, {{3,5,},     {2,4,},     {3,},       {0,},       {1,}       }},
+{ "Sn", 119, 120, 119.902200000, METAL2, 18,  0, {{2,4,6,},   {3,5},      {2,4,},     {3,},       {0,}       }},
+{ "Sb", 122, 121, 120.903800000, METAL,  19,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,},     {3,}       }},
+{ "Te", 128, 130, 129.906200000,     0 , 21,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,}     }},
+{ "I",  127, 127, 126.904500000,     0 , 25,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6},    {3,5,}     }},
+{ "Xe", 131, 132, 131.904100000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "Cs", 133, 133, 132.905430000, METAL ,  7,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Ba", 137, 138, 137.905200000, METAL ,  9,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "La", 139, 139, 138.906360000, METAL , 11,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Ce", 140, 140, 139.905400000, METAL2,  0,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
+{ "Pr", 141, 141, 140.907660000, METAL2,  0,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
+{ "Nd", 144, 142, 141.907719000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Pm", 145, 145, 144.912800000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Sm", 150, 152, 151.919700000, METAL2,  0,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Eu", 152, 153, 152.921200000, METAL2,  0,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Gd", 157, 158, 157.924099000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Tb", 159, 159, 158.925350000, METAL2,  0,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
+{ "Dy", 163, 164, 163.929200000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }}, /*  mw rounding uncertain */
+{ "Ho", 165, 165, 164.930300000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Er", 167, 166, 165.930300000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Tm", 169, 169, 168.934230000, METAL2,  0,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Yb", 173, 174, 173.938900000, METAL2,  0,  1, {{0,},       {0,},       {2,3,},     {0,},       {0,}       }},
+{ "Lu", 175, 175, 174.940800000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Hf", 178, 180, 179.946600000, METAL , 13,  1, {{0,},       {0,},       {4,},       {0,},       {0,}       }},
+{ "Ta", 181, 181, 180.948010000, METAL , 15,  1, {{0,},       {0,},       {5,},       {0,},       {0,}       }},
+{ "W",  184, 184, 183.951000000, METAL2, 17,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Re", 186, 187, 186.955800000, METAL2, 19,  1, {{0,},       {0,},       {2,4,6,7,}, {0,},       {0,}       }},
+{ "Os", 190, 192, 191.961500000, METAL2, 22,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
+{ "Ir", 192, 193, 192.962900000, METAL2, 22,  1, {{0,},       {0,},       {2,3,4,6,}, {0,},       {0,}       }},
+{ "Pt", 195, 195, 194.964800000, METAL2, 22,  1, {{0,},       {0,},       {2,4,},     {0,},       {0,}       }},
+{ "Au", 197, 197, 196.966560000, METAL , 24,  1, {{0,},       {0,},       {1,3,},     {0,},       {0,}       }},
+{ "Hg", 201, 202, 201.970617000, METAL2, 19,  1, {{0,},       {0,},       {1,2,},     {0,},       {0,}       }},
+{ "Tl", 204, 205, 204.974400000, METAL2, 18,  0, {{3,5,},     {2,4,},     {1,3,},     {0,},       {0,}       }},
+{ "Pb", 207, 208, 207.976627000, METAL2, 18,  0, {{2,4,6,},   {3,5},      {2,4,},     {3,},       {0,}       }},
+{ "Bi", 209, 209, 208.980390000, METAL , 19,  0, {{1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,},     {3,}       }},
+{ "Po", 209, 209, 208.982400000, METAL2, 20,  0, {{0,},       {1,3,5,7,}, {2,4,6,},   {3,5,},     {2,4,}     }},
+{ "At", 210, 210, 209.987100000,     0 , 22,  0, {{0,},       {0,},       {1,3,5,7,}, {2,4,6},    {3,5,}     }},
+{ "Rn", 222, 222, 222.017500000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
+{ "Fr", 223, 223, 223.019700000, METAL ,  0,  0, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Ra", 226, 226, 226.025410000, METAL ,  0,  0, {{0,},       {0,},       {2,},       {1,},       {0,}       }},
+{ "Ac", 227, 227, 227.027750000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Th", 232, 232, 232.038050000, METAL2,  0,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
+{ "Pa", 231, 231, 231.035880000, METAL2,  0,  1, {{0,},       {0,},       {3,4,5,},   {0,},       {0,}       }},
+{ "U",  238, 238, 238.050790000, METAL2,  0,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Np", 237, 237, 237.048170000, METAL2,  0,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Pu", 244, 244, 244.064200000, METAL2,  0,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Am", 243, 243, 243.061370000, METAL2,  0,  1, {{0,},       {0,},       {3,4,5,6,}, {0,},       {0,}       }},
+{ "Cm", 247, 247, 247.070300000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Bk", 247, 247, 247.070300000, METAL ,  0,  1, {{0,},       {0,},       {3,4,},     {0,},       {0,}       }},
+{ "Cf", 251, 251, 251.079600000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Es", 252, 252, 252.082800000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Fm", 257, 257, 257.095100000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "Md", 258, 258, 258.098600000, METAL ,  0,  1, {{0,},       {0,},       {3,},       {0,},       {0,}       }},
+{ "No", 259, 259, 259.100900000, METAL ,  0,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Lr", 260, 260, 260.105400000, METAL ,  0,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "Rf", 261, 261, 261.108700000, METAL ,  0,  1, {{0,},       {0,},       {1,},       {0,},       {0,}       }},
+{ "",     0,   0,   0.000000000,     0 ,  0,  0, {{0,},       {0,},       {0,},       {0,},       {0,}       }},
 
 };
  /*
@@ -634,7 +635,7 @@ char *fgetsTab( char *szLine, int len, FILE *f );
 /*******************************************************************/
 char *fgetsTab( char *szLine, int len, FILE *f )
 {
-    int  length=0, c;
+    int  length=0, c=0;
     len --;
     while ( length < len && EOF != (c = fgetc( f )) ) {
         if ( c == '\t' )
@@ -718,6 +719,31 @@ int my_fgets( char *szLine, int len, FILE *f, int *bTooLongLine )
     } while ( !length );
     return length;
 }
+#if ( FIX_READ_LONG_LINE_BUG == 1 )
+/********************************************************************/
+int my_fgetsUpToLfOrTab( char *szLine, int len, FILE *f )
+{
+    int  length;
+    char *p;
+    char szSkip[256];
+    int  bTooLongLine = 0;
+    do {
+        p = fgetsTab( szLine, len, f );
+        if ( !p ) {
+            return -1; /* end of file or cannot read */
+        }
+        bTooLongLine = ( (int)strlen(szLine) == len-1 && szLine[len-2] != '\n' );
+        LtrimRtrim( szLine, &length );
+    } while ( !length );
+    if ( bTooLongLine ) {
+        while ( p = fgetsTab( szSkip, sizeof(szSkip)-1, f ) ) {
+            if ( strchr( szSkip, '\n' ) )
+                break;
+        }
+    }
+    return length;
+}
+#else
 /********************************************************************/
 int my_fgetsUpToLfOrTab( char *szLine, int len, FILE *f )
 {
@@ -746,6 +772,7 @@ int my_fgetsUpToLfOrTab( char *szLine, int len, FILE *f )
     }
     return length;
 }
+#endif
 /******************************************************************/
 /* read not more than line_len bytes from an lf-terminated line   */
 /* if input line is too long quietly ignore the rest of the line  */
@@ -1070,7 +1097,7 @@ int MakeRemovedProtonsString( int nNumRemovedProtons, NUM_H *nNumExchgIsotopicH,
 /*************************************************************************/
 #define __MYTOLOWER(c) ( ((c) >= 'A') && ((c) <= 'Z') ? ((c) - 'A' + 'a') : (c) )
 
-#if ( !defined(_MSC_VER) || defined(__STDC__) && __STDC__ == 1 )
+#if ( defined(ADD_NON_ANSI_FUNCTIONS) || defined(__STDC__) && __STDC__ == 1 )
 /* support (VC++ Language extensions) = OFF && defined(INCHI_ANSI_ONLY) */
 int memicmp ( const void * p1, const void * p2, size_t length )
 {
