@@ -1,6 +1,6 @@
 /**********************************************************************
 Copyright (C) 1998-2001 by OpenEye Scientific Software, Inc.
-Some portions Copyright (C) 2001-2005 by Geoffrey Hutchison
+Some portions Copyright (C) 2001-2006 by Geoffrey Hutchison
 Portions Copyright (C) 2004-2005 by Chris Morley
 
 This file is part of the Open Babel project.
@@ -116,6 +116,7 @@ Write Options, e.g. -x3\n \
     OBMol &mol = *pmol;
     _mapcd.clear();
     bool chiralWatch=false;
+    bool setDimension = false;
 
     // Allows addition of further disconnected atoms to an existing molecule
     int offset = mol.NumAtoms(); 
@@ -132,8 +133,11 @@ Write Options, e.g. -x3\n \
     if (strlen(buffer) > 20) {
       char* dimension = buffer+20;
       dimension[2]='\0'; //truncate after 2D
-      if(strcmp(dimension,"2D") == 0)
-        mol.SetDimension(2);
+      if(strcmp(dimension,"3D") == 0)
+        {
+          mol.SetDimension(3);
+          setDimension = true;
+        }
     }
 
     if (!ifs.getline(buffer,BUFF_SIZE)) return(false); //comment
@@ -157,7 +161,7 @@ Write Options, e.g. -x3\n \
       {
         mol.ReserveAtoms(natoms);
         double x,y,z;
-        char type[5];
+        char type[8];
         vector3 v;
         OBAtom atom;
         int charge, scanArgs, stereo;
@@ -166,7 +170,7 @@ Write Options, e.g. -x3\n \
           if (!ifs.getline(buffer,BUFF_SIZE))
             return(false);
 
-          scanArgs = sscanf(buffer,"%lf %lf %lf %s %*d %d %d",&x,&y,&z,type,&charge, &stereo);
+          scanArgs = sscanf(buffer,"%lf %lf %lf %5s %*d %d %d",&x,&y,&z,type,&charge, &stereo);
           if (scanArgs <4)
             return(false);
           v.SetX(x);v.SetY(y);v.SetZ(z);
@@ -178,47 +182,47 @@ Write Options, e.g. -x3\n \
             atom.SetIsotope(iso);
 
           if (scanArgs >= 5)
-	    {
-	      switch (charge)
-		{
-		case 0: break;
-		case 3: atom.SetFormalCharge(1); break;
-		case 2: atom.SetFormalCharge(2); break;
-		case 1: atom.SetFormalCharge(3); break;
-		case 5: atom.SetFormalCharge(-1); break;
-		case 6: atom.SetFormalCharge(-2); break;
-		case 7: atom.SetFormalCharge(-3); break;
-		}
-	    }
+            {
+              switch (charge)
+                {
+                case 0: break;
+                case 3: atom.SetFormalCharge(1); break;
+                case 2: atom.SetFormalCharge(2); break;
+                case 1: atom.SetFormalCharge(3); break;
+                case 5: atom.SetFormalCharge(-1); break;
+                case 6: atom.SetFormalCharge(-2); break;
+                case 7: atom.SetFormalCharge(-3); break;
+                }
+            }
 
           if (scanArgs == 6) // set a stereo mark
-	    {
-                //Stereo configuration: 0 none; 1 odd parity; 2 even parity; 3 unspecified)
-                if (stereo == 2)
-		  {
-		    chiralWatch=true;
-		    atom.SetAntiClockwiseStereo();
-		  }
-                else if (stereo == 1)
-		  {
-		    chiralWatch=true;
-		    atom.SetClockwiseStereo();
-		  }
-                else if(stereo == 3)
-		  {
-		    chiralWatch=true;
-		    atom.SetChiral();
-		  }
-	    }
+            {
+              //Stereo configuration: 0 none; 1 odd parity; 2 even parity; 3 unspecified)
+              if (stereo == 2)
+                {
+                  chiralWatch=true;
+                  atom.SetAntiClockwiseStereo();
+                }
+              else if (stereo == 1)
+                {
+                  chiralWatch=true;
+                  atom.SetClockwiseStereo();
+                }
+              else if(stereo == 3)
+                {
+                  chiralWatch=true;
+                  atom.SetChiral();
+                }
+            }
 
           if (!mol.AddAtom(atom))
             return(false);
-	  if(chiralWatch)  // fill the map with data for each chiral atom
-	    _mapcd[mol.GetAtom(mol.NumAtoms())] = new OBChiralData;
+          if(chiralWatch)  // fill the map with data for each chiral atom
+            _mapcd[mol.GetAtom(mol.NumAtoms())] = new OBChiralData;
           atom.Clear();
         }
 
-        int start,end,order,flag;
+        unsigned int start,end,order,flag;
         for (i = 0;i < nbonds;i++) {
           flag = 0;
           if (!ifs.getline(buffer,BUFF_SIZE))
@@ -242,21 +246,21 @@ Write Options, e.g. -x3\n \
 
           if (!mol.AddBond(start+offset,end+offset,order,flag)) return(false);
 
-	  // after adding a bond to atom # "start+offset"
-	  // search to see if atom is bonded to a chiral atom
-	  map<OBAtom*,OBChiralData*>::iterator ChiralSearch;
-	  ChiralSearch = _mapcd.find(mol.GetAtom(start+offset));
-	  if (ChiralSearch!=_mapcd.end())
-	    {
-	      (ChiralSearch->second)->AddAtomRef(end+offset, input);
-	    }
-	  // after adding a bond to atom # "end + offset"
-	  // search to see if atom is bonded to a chiral atom
-	  ChiralSearch = _mapcd.find(mol.GetAtom(end+offset));
-	  if (ChiralSearch!=_mapcd.end())
-	    {
-	      (ChiralSearch->second)->AddAtomRef(start+offset, input);
-	    }
+          // after adding a bond to atom # "start+offset"
+          // search to see if atom is bonded to a chiral atom
+          map<OBAtom*,OBChiralData*>::iterator ChiralSearch;
+          ChiralSearch = _mapcd.find(mol.GetAtom(start+offset));
+          if (ChiralSearch!=_mapcd.end())
+            {
+              (ChiralSearch->second)->AddAtomRef(end+offset, input);
+            }
+          // after adding a bond to atom # "end + offset"
+          // search to see if atom is bonded to a chiral atom
+          ChiralSearch = _mapcd.find(mol.GetAtom(end+offset));
+          if (ChiralSearch!=_mapcd.end())
+            {
+              (ChiralSearch->second)->AddAtomRef(start+offset, input);
+            }
         }
 
         //CM start 18 Sept 2003
@@ -327,28 +331,45 @@ Write Options, e.g. -x3\n \
       }
         
     //Get property lines
-    while (ifs.getline(buffer,BUFF_SIZE)) {
-      if (strstr(buffer,"<")) {
-        string buff(buffer);
-        size_t lt=buff.find("<")+1;
-        size_t rt = buff.find_last_of(">");
-        string attr = buff.substr(lt,rt-lt);
-
-        // sometimes we can hit more data than BUFF_SIZE, so we'll use a std::string
-        getline(ifs, buff);
-        Trim(buff);
-
-        OBPairData *dp = new OBPairData;
-        dp->SetAttribute(attr);
-        dp->SetValue(buff);
-        mol.SetData(dp);
+    while (ifs.getline(buffer,BUFF_SIZE))
+      {
+        if (strstr(buffer,"<"))
+          {
+            string buff(buffer);
+            size_t lt=buff.find("<")+1;
+            size_t rt = buff.find_last_of(">");
+            string attr = buff.substr(lt,rt-lt);
+ 
+            // sometimes we can hit more data than BUFF_SIZE, so we'll use a std::string
+            string line;
+            buff.clear();
+            while (getline(ifs, line))
+              {
+                Trim(line);
+                if (line.size())
+                  {
+                    buff.append(line);
+                    buff += "\n";
+                  }
+                else
+                  break;
+              }
+            Trim(buff);
+ 
+            OBPairData *dp = new OBPairData;
+            dp->SetAttribute(attr);
+            dp->SetValue(buff);
+            mol.SetData(dp);
+          }
+        if (!strncmp(buffer,"$$$$",4)) break;
+        if (!strncmp(buffer,"$MOL",4)) break;
       }
-      // end RWT    
-
-      if (!strncmp(buffer,"$$$$",4)) break;
-      if (!strncmp(buffer,"$MOL",4)) break;
-    }
-
+  
+    if (!setDimension && mol.Has3D())
+      mol.SetDimension(3);
+    else if (!setDimension && !mol.Has3D())
+      mol.SetDimension(2);
+  
     return(true);
 
   }
@@ -421,8 +442,8 @@ Write Options, e.g. -x3\n \
               }
           }
 
-        sprintf(buff,"%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d V2000",
-                mol.NumAtoms(),mol.NumBonds(),0,0,0,0,0,0,0,0,999);
+        snprintf(buff, BUFF_SIZE, "%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d V2000",
+                 mol.NumAtoms(),mol.NumBonds(),0,0,0,0,0,0,0,0,999);
         ofs << buff << endl;
 
         OBAtom *atom;
@@ -440,12 +461,12 @@ Write Options, e.g. -x3\n \
             charge=0; break;
           }
 
-          sprintf(buff,"%10.4f%10.4f%10.4f %-3s%2d%3d%3d%3d%3d",
-                  atom->GetX(),
-                  atom->GetY(),
-                  atom->GetZ(),
-                  (etab.GetSymbol(atom->GetAtomicNum())),
-                  0,charge,0,0,0);    
+          snprintf(buff, BUFF_SIZE, "%10.4f%10.4f%10.4f %-3s%2d%3d%3d%3d%3d",
+                   atom->GetX(),
+                   atom->GetY(),
+                   atom->GetZ(),
+                   (etab.GetSymbol(atom->GetAtomicNum())),
+                   0,charge,0,0,0);    
           ofs << buff << endl;
         }
 
@@ -465,11 +486,11 @@ Write Options, e.g. -x3\n \
                   if (flag & OB_WEDGE_BOND) stereo=1;
                   if (flag & OB_HASH_BOND ) stereo=6;
                 }
-              sprintf(buff,"%3d%3d%3d%3d%3d%3d",
-                      bond->GetBeginAtomIdx(),
-                      bond->GetEndAtomIdx(),
-                      bond->GetBO(),
-                      stereo,0,0);
+              snprintf(buff, BUFF_SIZE, "%3d%3d%3d%3d%3d%3d",
+                       bond->GetBeginAtomIdx(),
+                       bond->GetEndAtomIdx(),
+                       bond->GetBO(),
+                       stereo,0,0);
               ofs << buff << endl;
             }
 
@@ -841,9 +862,9 @@ Write Options, e.g. -x3\n \
     time_t long_time;
     time( &long_time );
     ts = localtime( &long_time ); 
-    sprintf(td,"%02d%02d%02d%02d%02d", ts->tm_mon+1, ts->tm_mday, 
-            ((ts->tm_year>=100)? ts->tm_year-100 : ts->tm_year),
-            ts->tm_hour, ts->tm_min);
+    snprintf(td, sizeof(td), "%02d%02d%02d%02d%02d", ts->tm_mon+1, ts->tm_mday, 
+             ((ts->tm_year>=100)? ts->tm_year-100 : ts->tm_year),
+             ts->tm_hour, ts->tm_min);
     return td;
   }
 
