@@ -18,18 +18,10 @@ GNU General Public License for more details.
 #include "obconversion.h"
 #include "obmolecformat.h"
 
-#if !HAVE_SNPRINTF
-extern "C" int snprintf( char *, size_t, const char *, /* args */ ...);
-#endif
-
 #include <vector>
 #include <map>
 
-#ifdef HAVE_SSTREAM
 #include <sstream>
-#else
-#include <strstream>
-#endif
 
 using namespace std;
 namespace OpenBabel
@@ -128,7 +120,6 @@ namespace OpenBabel
     if (!pConv->IsOption("b",OBConversion::INOPTIONS))
       mol.ConnectTheDots();
 
-    if (mol.NumAtoms() < 250) // Minimize time required on real proteins
       if (!pConv->IsOption("s",OBConversion::INOPTIONS) && !pConv->IsOption("b",OBConversion::INOPTIONS))
         mol.PerceiveBondOrders();
 
@@ -398,11 +389,7 @@ namespace OpenBabel
 
   static bool ParseConectRecord(char *buffer,OBMol &mol)
   {
-#ifdef HAVE_SSTREAM
     stringstream errorMsg;
-#else
-    strstream errorMsg;
-#endif
     string clearError;
 
     // Setup strings and string buffers
@@ -573,16 +560,13 @@ namespace OpenBabel
     int res_num;
     bool het=true;
 
-    //  sprintf(buffer,"HEADER    PROTEIN");
-    //  ofs << buffer << endl;
-
     if (strlen(mol.GetTitle()) > 0)
-      sprintf(buffer,"COMPND    %s ",mol.GetTitle());
+      snprintf(buffer, BUFF_SIZE, "COMPND    %s ",mol.GetTitle());
     else
-      sprintf(buffer,"COMPND    UNNAMED");
+      snprintf(buffer, BUFF_SIZE, "COMPND    UNNAMED");
     ofs << buffer << endl;
 
-    sprintf(buffer,"AUTHOR    GENERATED BY OPEN BABEL %s",BABEL_VERSION);
+    snprintf(buffer, BUFF_SIZE, "AUTHOR    GENERATED BY OPEN BABEL %s",BABEL_VERSION);
     ofs << buffer << endl;
 
     // before we write any records, we should check to see if any coord < -1000
@@ -616,7 +600,8 @@ namespace OpenBabel
     for (i = 1; i <= mol.NumAtoms(); i++)
       {
         atom = mol.GetAtom(i);
-        strcpy(type_name,etab.GetSymbol(atom->GetAtomicNum()));
+        strncpy(type_name, etab.GetSymbol(atom->GetAtomicNum()), sizeof(type_name));
+        type_name[sizeof(type_name) - 1] = '\0';
 
         //two char. elements are on position 13 and 14 one char. start at 14
         if (strlen(type_name) > 1)
@@ -624,8 +609,8 @@ namespace OpenBabel
         else
 	  {
             char tmp[10];
-            strcpy(tmp, type_name);
-            sprintf(type_name, " %-3s", tmp);
+            strncpy(tmp, type_name, 10);
+            snprintf(type_name, sizeof(type_name), " %-3s", tmp);
 	  }
 
         if ( (res = atom->GetResidue()) )
@@ -641,7 +626,7 @@ namespace OpenBabel
 		  {
                     char tmp[10];
                     strcpy(tmp, type_name);
-                    sprintf(padded_name," %-3s", tmp);
+                    snprintf(padded_name, sizeof(padded_name), " %-3s", tmp);
                     strncpy(type_name,padded_name,4);
                     type_name[4] = '\0';
 		  }
@@ -660,7 +645,7 @@ namespace OpenBabel
         else
 	  {
             strcpy(the_res,"UNK");
-            sprintf(padded_name,"%s",type_name);
+            snprintf(padded_name,sizeof(padded_name), "%s",type_name);
             strncpy(type_name,padded_name,4);
             type_name[4] = '\0';
             res_num = 1;
@@ -669,7 +654,7 @@ namespace OpenBabel
         element_name = etab.GetSymbol(atom->GetAtomicNum());
         if (strlen(element_name) == 2)
 	  element_name[1] = toupper(element_name[1]);
-        sprintf(buffer,"%s%5d %-4s %-3s  %4d    %8.3f%8.3f%8.3f  1.00  0.00          %2s  \n",
+        snprintf(buffer, BUFF_SIZE, "%s%5d %-4s %-3s  %4d    %8.3f%8.3f%8.3f  1.00  0.00          %2s  \n",
                 het?"HETATM":"ATOM  ",
                 i,
                 type_name,
@@ -690,27 +675,26 @@ namespace OpenBabel
         atom = mol.GetAtom(i);
         if (atom->GetValence() <= 4)
 	  {
-            sprintf(buffer,"CONECT%5d", i);
+            snprintf(buffer, BUFF_SIZE, "CONECT%5d", i);
             ofs << buffer;
             for (nbr = atom->BeginNbrAtom(k);nbr;nbr = atom->NextNbrAtom(k))
 	      {
-                sprintf(buffer,"%5d", nbr->GetIdx());
+                snprintf(buffer, BUFF_SIZE, "%5d", nbr->GetIdx());
                 ofs << buffer;
 	      }
             for (count = 0; count < (4 - (int)atom->GetValence()); count++)
 	      {
-                sprintf(buffer, "     ");
+                snprintf(buffer, BUFF_SIZE, "     ");
                 ofs << buffer;
 	      }
             ofs << "                                       " << endl;
 	  }
       }
-    sprintf(buffer,"MASTER        0    0    0    0    0    0    0    0 ");
+    snprintf(buffer, BUFF_SIZE, "MASTER        0    0    0    0    0    0    0    0 ");
     ofs << buffer;
-    sprintf(buffer,"%4d    0 %4d    0",mol.NumAtoms(),mol.NumAtoms());
-    ofs << buffer << endl;
-    sprintf(buffer,"END");
-    ofs << buffer << endl;
+    snprintf(buffer, BUFF_SIZE, "%4d    0 %4d    0\n",mol.NumAtoms(),mol.NumAtoms());
+    ofs << buffer;
+    ofs << "END\n";
     return(true);
   }
 
