@@ -1,5 +1,6 @@
 /**********************************************************************
-Copyright (C) 2005 by Chris Morley
+Copyright (C) 2005-2006 by Chris Morley
+Some portions Copyright (C) 2006 by Geoffrey R. Hutchison
  
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -162,7 +163,8 @@ bool XMLConversion::ReadXML(XMLBaseFormat* pFormat, OBBase* pOb)
 
 	//**Parse
 	int result=1;
-	while(_SkipNextRead || (result=xmlTextReaderRead(_reader))==1) //read may not be called
+	while(GetInStream()->good() && 
+	      (_SkipNextRead || (result=xmlTextReaderRead(_reader))==1)) //read may not be called
 	{
 		_SkipNextRead=false;
 		if(_LookingForNamespace)
