@@ -1,7 +1,7 @@
 /**********************************************************************
 obrotate = rotate a tortional bond matched by a SMART pattern
 Copyright (C) 2003 Fabien Fontaine
-Some portions Copyright (C) 2004-2005 Geoffrey R. Hutchison
+Some portions Copyright (C) 2004-2006 Geoffrey R. Hutchison
  
 This file is part of the Open Babel project.
 For more information, see <http://openbabel.sourceforge.net/>
@@ -27,6 +27,12 @@ GNU General Public License for more details.
   obrotate "[nH]ccccc[O,C][C,O]" test.sdf 1 6 7 8 180.0
 */
 
+// used to set import/export for Cygwin DLLs
+#ifdef WIN32
+#define USING_OBDLL
+#endif
+
+#include "babelconfig.h"
 #include "mol.h"
 #include "parsmart.h"
 #include "rotamer.h"
